package com.biganto.visual.roompark.domain.model

import com.biganto.visual.roompark.data.repository.db.requrey.TitledPhoto
import com.biganto.visual.roompark.data.repository.db.requrey.model.ArticleEntity
import com.biganto.visual.roompark.data.repository.db.requrey.model.FeedEntity
import java.util.*

/**
 * Created by Vladislav Bogdashkin on 23.09.2019.
 */

const val DEFAULT_ROOM_PARK_PREVIEW = "https://room-park.ru/assets/news_articles/preview/00/00/00/15-fe1886.jpeg"

data class FeedModel(val feedId:Int, val title:String, val alias:String? = null)

data class FeedsHeaderModel(val feeds:List<FeedModel>)

data class ArticlePreviewModel(
    val articleId:Int,
    val published: Date,
    val title:String,
    val announce:String,
    val previewUrl:String,
    val isRead:Boolean
    ){
    override fun equals(other: Any?): Boolean {
        if (other is ArticlePreviewModel)
            return this.articleId == other.articleId
        return super.equals(other)
    }
}

data class ArticlesPreviewModel(val parentFeedId:Int,val articles:List<ArticlePreviewModel>)


data class ArticleModel(
    val articleId:Int,
    val published: Date,
    val title:String,
    val htmlBody:String,
    val previewUrl:String,
    val bottomPhotoList:List<TitledPhoto>?,
    val isRead:Boolean
)

fun fromEntity(entity: FeedEntity):FeedModel = FeedModel(
    feedId = entity.id,
    title = entity.title,
    alias = entity.alias
)

fun fromEntity(entity: ArticleEntity):ArticlePreviewModel = ArticlePreviewModel(
    articleId = entity.id,
    published = entity.published,
    title = entity.title,
    announce = entity.announce?:"",
    previewUrl = entity.preview?:"",
    isRead = false
)

fun fromEntity(parentId:Int,entity: List<ArticleEntity>):ArticlesPreviewModel =
    ArticlesPreviewModel(
        parentFeedId = parentId,
        articles = fromEntity(entity,::fromEntity)
)

fun fromEntity(entity: ArticleEntity,read:Boolean) : ArticleModel =
    ArticleModel(
        articleId = entity.id,
        published = entity.published,
        title = entity.title,
        htmlBody = entity.body!!,
        previewUrl = entity.preview?:DEFAULT_ROOM_PARK_PREVIEW,
        bottomPhotoList = entity.photo,
        isRead = read
    )

fun <E,M> fromEntity(raw: List<E>,block:(E)->M):List<M> = List(raw.size) { index-> block(raw[index])}
